@@ -85,7 +85,7 @@ BEGIN
 # package variables 
 ########################################################################
 
-our $VERSION = '1.38';
+our $VERSION = '1.40';
 
 my %defaultz = 
 (
@@ -198,6 +198,11 @@ sub find_libs
         pop @dirpath
     }
 
+    # HAK ALERT: the regex does nothing for security,
+    # just dodges -T.
+
+    @libz   = map { m{ (.+) }x } @libz;
+
     # caller gets back the existing lib paths 
     # (including volume) walking up the path 
     # from $FindBin::Bin -> root.
@@ -344,8 +349,6 @@ sub import
 
     require lib;
 
-    $DB::single = 1;
-
     lib->import( @libz );
   }
 
